# ----------- Define scan ranges -----------

# Use space-separated or comma-separated floats/integers (can be bracketed)
SCATTERING_LENGTH_RANGE="[85.0]"
POLAR_ANGLE_RANGE="[0]"
AZIMUTHAL_ANGLE_RANGE="[0.0]"
NUM_ATOMS_LIST="[90000]"
CHUNK_SIZE=1

# ----------- Count total combinations for SLURM array -----------

# Strip brackets for Bash processing (for counting only)
scatteringLengths=($(echo "$SCATTERING_LENGTH_RANGE" | tr -d '[],')) 
polarAngles=($(echo "$POLAR_ANGLE_RANGE" | tr -d '[],')) 
azimuthalAngles=($(echo "$AZIMUTHAL_ANGLE_RANGE" | tr -d '[],')) 
numAtoms=($(echo "$NUM_ATOMS_LIST" | tr -d '[],')) 

totalJobs=$((${#scatteringLengths[@]} * ${#polarAngles[@]} * ${#azimuthalAngles[@]} * ${#numAtoms[@]}))
numArrayJobs=$(( (totalJobs + CHUNK_SIZE - 1) / CHUNK_SIZE ))

echo "Total number of jobs: $totalJobs"
echo "Number of SLURM array jobs: $numArrayJobs"
echo "Running SLURM job array from 1 to ${numArrayJobs}"

# ----------- Submit SLURM array job -----------

sbatch --export=SCATTERING_LENGTH_RANGE="$SCATTERING_LENGTH_RANGE",POLAR_ANGLE_RANGE="$POLAR_ANGLE_RANGE",AZIMUTHAL_ANGLE_RANGE="$AZIMUTHAL_ANGLE_RANGE",NUM_ATOMS_LIST="$NUM_ATOMS_LIST",CHUNK_SIZE=$CHUNK_SIZE << EOF
#!/bin/bash
#SBATCH --partition=gpu-single
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=1
#SBATCH --cpus-per-task=8
#SBATCH --gres=gpu:1
#SBATCH --mem=16G
#SBATCH --time=00:40:00
#SBATCH --job-name=simulation
#SBATCH --error=simulation_%A_%a.err
#SBATCH --output=simulation_%A_%a.out
#SBATCH --array=1-${numArrayJobs}

echo "Working Directory:                    $PWD"
echo "Running on host                       $HOSTNAME"
echo "Job id:                               $SLURM_JOB_ID"
echo "Job name:                             $SLURM_JOB_NAME"
echo "Number of nodes allocated to job:     $SLURM_JOB_NUM_NODES"
echo "Number of GPUs allocated to job:      $SLURM_GPUS"
echo "SLURM task index:                     \$SLURM_ARRAY_TASK_ID"

# Load MATLAB
module load math/matlab/R2023a

echo Directory is pwd
echo "Initiating Job..."

# Run MATLAB wrapper with this batch index
matlab -nodisplay -nosplash -r "Scripts.run_hybrid_worker_wrapper(\$SLURM_ARRAY_TASK_ID)"

echo "Job terminated successfully"

exit
EOF